const tooltipQuicker = (() => {
    const tooltipQuickerClass = ".tooltip-quicker";
    return {
        /**
         * Function goes through all of the children of the parent and
         * bind events
         */
        createTooltips: (tooltipBind, eventName) => {
            Array.from(tooltipBind, (element, index) => {
                const tooltipContent = element.nextElementSibling;
                const tooltipContentChildren = tooltipContent.children;

                // Assing an event to the element.
                tooltipQuicker.addEvent(eventName, element);
                Array.from(tooltipContentChildren).filter(elements => {
                    if(elements.classList.contains('tooltip-close-icon')) {
                        const closeIcon = elements;
                        tooltipQuicker.addEvent('click', closeIcon);
                    }
                });
            });
        },
        /**
         * Function finds the right parent and the right tooltip-quicker sibling
         * Then it goes to createTooltips function
         */
        addTooltip: (parentElem, eventName) => {
            const mainParentElem = parentElem;
            const tooltipBind = document.querySelectorAll(`${ mainParentElem } [tip-quick] > ${ tooltipQuickerClass }`);
            tooltipQuicker.createTooltips(tooltipBind, eventName);
        },

        // Function attaches events to tooltip divs
        addEvent: (eventName, parentElem) => {
            const windowOutherWidth = window.outerWidth;
            // Separate events according to screen size.
            // 1. for mobile and a few types of tablets, tooltip will attach click event.
            // 2. for desktop tooltip will attach hover and possible click event.
            if (parentElem.classList.value !== "tooltip-close-icon") {
                if (windowOutherWidth <= 768 || windowOutherWidth === 1024) {
                    parentElem.addEventListener('click', tooltipQuicker.events.showTooltipContent, false);
                } else {
                    eventName.eventType === "hover" ? eventName.eventType = "mouseenter" : false;
                    parentElem.addEventListener(eventName.eventType, tooltipQuicker.events.showTooltipContent, false);
                    eventName.dissapear ? parentElem.addEventListener('mouseleave', tooltipQuicker.events.hideTooltipContent, false) : false;
                }
            } else {
                // Attach click event for close icon with the purpose of closing modal on mobile and desktop.
                parentElem.addEventListener(eventName, tooltipQuicker.events.closeTooltipByIcon, false);
            }
        },

        events: (() => {
            return {
                showTooltipContent: (e) => {
                    if(e.type === "click") {
                        e.target.nextElementSibling.classList.add('active');
                    } else {
                        e.target.nextElementSibling.classList.add('active');
                    }
                },
                hideTooltipContent: (e) => {
                    e.target.nextElementSibling.classList.remove('active');
                }, 
                closeTooltipByIcon: (e) => {
                    e.target.parentElement.classList.remove('active');
                }
            }
        })()
    };
})();

/**
 * 1. First parameter implies the input div and the start place.
 * 2. Second paremeter is an object that specifies how your tooltip will behave, on click or hover, will it dissapear or stay in the same place.
 */

tooltipQuicker.addTooltip('.js-parent-1', { eventType: 'click', dissapear: false });